This is a collection of parsers for propriatory statement formats, produced by certain Lithuanian banks. It is a plugin for ofxstatement.

Statements from these banks are currently supported:

* Swedbank - CSV files
* DNB - FIDAVISTA xml files
